@@ -14,6 +14,7 @@ import httplib2
 import os
 
 import twitter
+import dateutil.parser
 import feedparser
 import mechanize
 import fbconsole
@@ -82,6 +83,18 @@ class Command(BaseCommand):
                         verb = "updated"
                     self.stderr.write("%s %s\n" % (verb, instance))
 
+    def update_counter(self, counter, t):
+        """This method is used to update the counter"""
+        if not isinstance(counter, Counter):
+            raise TypeError("counter must be a collections.Counter object")
+        if isinstance(t, datetime.datetime):
+            counter[t.date()] += 1
+        elif isinstance(t, datetime.date):
+            counter[t] += 1
+        else:
+            msg = "t must be a datetime.datetime or datetime.date instance!"
+            raise TypeError(m)
+
     def update_twitter(self):
         for account in models.Account.objects.filter(type__exact="twitter"):
         
@@ -102,7 +115,7 @@ class Command(BaseCommand):
             fmt_str = "%a %b %d %H:%M:%S +0000 %Y"
             for status in statuses:
                 t = datetime.datetime.strptime(status.created_at, fmt_str)
-                counter[t.date()] += 1
+                self.update_counter(counter, t)
 
             # insert data into the database
             self.update_db(account, counter)
@@ -117,18 +130,12 @@ class Command(BaseCommand):
         
             # parse all of the dates. 
             #
-            # NOTE: this is not properly parsing out the timezone
-            # information. %z directive doesn't work? at the end of
-            # the day, it doesn't really matter because it will make
-            # the same mistake consistenly, but it might be nice to
-            # fix at some point
+            # NOTE: this uses python-dateutil instead of datetime to
+            # properly handle the timezone information
             counter = Counter()
-            fmt_str = "%a, %d %b %Y %H:%M:%S %z"
-            fmt_str = ' '.join(fmt_str.split()[:-1]) # %z does not work
             for item in items:
-                t_str = ' '.join(item['published'].split()[:-1])
-                t = datetime.datetime.strptime(t_str, fmt_str)
-                counter[t.date()] += 1
+                t = dateutil.parser.parse(item['published']).date()
+                self.update_counter(counter, t)
 
             # insert data into the database
             self.update_db(account, counter)
@@ -260,7 +267,7 @@ class Command(BaseCommand):
             fmt_str = "%Y-%m-%dT%H:%M:%S+0000"
             for status in statuses["data"]:
                 t = datetime.datetime.strptime(status["created_time"], fmt_str)
-                counter[t.date()] += 1
+                self.update_counter(counter, t)
 
             # insert data into the database
             self.update_db(account, counter)
@@ -308,7 +315,7 @@ class Command(BaseCommand):
             counter = Counter()
             for status in result["values"]:
                 t = datetime.datetime.fromtimestamp(status['timestamp']/1000.)
-                counter[t.date()] += 1
+                self.update_counter(counter, t)
 
             # insert data into the database
             self.update_db(account, counter)
